- threshold
estimated threshold, at and beyond which the empirical
sensitivity or specificity is the smallest no less than the controlled level
s0.
- hss
hss[1]: empirical point estimate of specificity at controlled
sensitivity, or vice versa; hss[2]: oscillating bias-corrected estimate.
- hvar1
estimated variance component from cases if specificity at
controlled sensitivity is estimated, or from controls otherwise.
- hvar2
estimated variance component from controls if specificity at
controlled sensitivity is estimated, or from cases otherwise.
- hvar
exact bootstrap variance estimate, =hvar1+hvar2.
- btpdf
exact bootstrap probability mass function at (0:n0)/n0 with n0
being the size of controls if sensitivity is controlled, or at (0:n1)/n1
otherwise.
- wald_ci
wald_ci[1,]: Wald confidence interval using hss[1];
wald_ci[2,]: Wald confidence interval using hss[2].
- pct_ci
percentile confidence interval.
- scr_ci
scr_ci[1,]: score confidence interval using hss[1];
scr_ci[2,]: score confidence interval using hss[2].
- zq_ci
exact bootstrap version of the BTII in Zhou and Qin (2005,
Statistics in Medicine 24, pp 465--477).